@@ -3,8 +3,8 @@
 */
 
 #include "../rss/icrss.h"
-#include "../VERSION"
+#include "../tmp/INSTALL.im"
 
 char
     version[] = VERSION,
-    release[] = RELEASE;
+    release[] = YEARS;
